--      ██████╗  █████╗ ███████╗████████╗███████╗██╗
--      ██╔══██╗██╔══██╗██╔════╝╚══██╔══╝██╔════╝██║
--      ██████╔╝███████║███████╗   ██║   █████╗  ██║
--      ██╔═══╝ ██╔══██║╚════██║   ██║   ██╔══╝  ██║
--      ██║     ██║  ██║███████║   ██║   ███████╗███████╗
--      ╚═╝     ╚═╝  ╚═╝╚══════╝   ╚═╝   ╚══════╝╚══════╝

-- ===================================================================
-- Initialization
-- ===================================================================


local awful = require("awful")
local lain = require("lain")
local quake = lain.util.quake({app="alacritty", followtag=true, argname = '--class %s', extra="--option=window.opacity=1.0 --option=\"colors.primary.background='#000d2b'\" -e tmux", height=0.3})

local pastel = {}


-- ===================================================================
-- Pastel setup
-- ===================================================================


pastel.initialize = function()
    -- Import components
    require("components.pastel.wallpaper")

    -- Import panels
    local top_panel = require("components.pastel.top-panel")

    -- Set up each screen (add tags & panels)
    awful.screen.connect_for_each_screen(function(s)
        for i = 1, 9, 1
        do
            awful.tag.add(tostring(i), {
                layout = awful.layout.suit.tile,
                screen = s,
                selected = i == 1
            })
        end

        s.quake = quake

        -- Only add the top panel on the primary screen
        if s.index == 1 then
            top_panel.create(s)
        end

    end)
end

return pastel
